numpy.polynomial.Legendre
=========================

.. currentmodule:: numpy.polynomial

.. autoclass:: Legendre

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Legendre.__init__
         Legendre.convert
         Legendre.copy
         Legendre.cutdeg
         Legendre.degree
         Legendre.deriv
         Legendre.has_samecoef
         Legendre.has_samedomain
         Legendre.has_samewindow
         Legendre.integ
         Legendre.linspace
         Legendre.mapparms
         Legendre.roots
         Legendre.trim
         Legendre.truncate



   

